@@ -1,6 +1,6 @@
+import os
 from os.path import dirname, join
 
-import numpy as np
 import h5py
 
 from bokeh.io import curdoc
@@ -9,34 +9,37 @@ from bokeh.models import ColumnDataSource
 from bokeh.models.widgets import Select
 from bokeh.plotting import figure
 
-data_select = Select(title="Output:", value="hip_strength", options=["hip_strength", "knee_strength"])
+app_dir = dirname(__file__)
+
+if 'demo_data.hdf5' not in os.listdir(app_dir):
+    import sys
+    sys.path.append(app_dir)
+    from create_hdf5 import generate_data
+    generate_data(app_dir)
+
+
+options = ['Gaussian', 'Exponential', 'Chi Square', 'Alpha', 'Beta']
+data_select = Select(title="Distribution:", value=options[0],
+                     options=options)
 
 source = ColumnDataSource(data=dict(x=[], y=[]))
 
 p = figure(plot_height=600, plot_width=800, title="", toolbar_location=None)
-p.line(x="x", y="y", source=source)
+p.line(x="x", y="y", source=source, line_width=2)
+p.background_fill_color = "#efefef"
 
-# Fast direct read from hdf5
-def get_data(f, name):
-    shape = f[name].shape
-    # Empty array
-    data = np.empty(shape, dtype=np.float64)
-    # read_direct to empty arrays
-    f[name].read_direct(data)
-    return data
 
 def select_data():
     data_val = data_select.value
-    with h5py.File(join(dirname(__file__), 'demo_data.hdf5'), 'r') as f:
-        return get_data(f, data_val)
+    with h5py.File(join(app_dir, 'demo_data.hdf5'), 'r') as f:
+        return f[data_val]['x'][:], f[data_val]['pdf'][:]
+
 
 def update():
-    # hardcoded length of 100
-    x = list(range(1, 101))
-    y = select_data()
-
+    x, y = select_data()
     source.data = dict(x=x, y=y)
 
+
 data_select.on_change('value', lambda attr, old, new: update())
 
 inputs = widgetbox(data_select, width=300)
