@@ -10,9 +10,9 @@ dot = figure(title="Categorical Dot Plot", tools="", toolbar_location=None,
 dot.segment(0, factors, x, factors, line_width=2, line_color="green", )
 dot.circle(x, factors, size=15, fill_color="orange", line_color="green", line_width=3, )
 
-factors = ["foo", "bar", "baz"]
-x = ["foo", "foo", "foo", "bar", "bar", "bar", "baz", "baz", "baz"]
-y = ["foo", "bar", "baz", "foo", "bar", "baz", "foo", "bar", "baz"]
+factors = ["foo 123", "bar:0.2", "baz-10"]
+x = ["foo 123", "foo 123", "foo 123", "bar:0.2", "bar:0.2", "bar:0.2", "baz-10",  "baz-10",  "baz-10"]
+y = ["foo 123", "bar:0.2", "baz-10",  "foo 123", "bar:0.2", "baz-10",  "foo 123", "bar:0.2", "baz-10"]
 colors = [
     "#0B486B", "#79BD9A", "#CFF09E",
     "#79BD9A", "#0B486B", "#79BD9A",
