@@ -40,12 +40,16 @@ TOOLTIPS = """
 """.format(mass_format=mass_format)
 
 p = figure(plot_width=900, plot_height=450, tooltips=TOOLTIPS, title='Densities by Atomic Mass')
-p.circle('atomic_mass', 'density', size=12, source=data, color='type_color',
-         line_color="black", legend='metal', fill_alpha=0.9)
+p.background_fill_color = "#fafafa"
 
+p.circle('atomic_mass', 'density', size=12, source=data, color='type_color',
+         line_color="black", legend='metal', alpha=0.9)
+
+p.legend.glyph_width = 30
+p.legend.glyph_height = 30
 p.xaxis.axis_label= 'Atomic Mass'
 p.yaxis.axis_label= 'Density'
-p.grid.grid_line_color = None
+p.xgrid.grid_line_color = None
 p.toolbar_location = None
 
 l = p.legend[0]
