@@ -2,13 +2,14 @@ import numpy as np
 
 from bokeh.plotting import figure, show, output_file
 
-x = np.linspace(0.1, 5, 100)
+x = np.linspace(0.1, 5, 80)
 
 p = figure(title="log axis example", y_axis_type="log",
-           y_range=(0.001, 10**22))
+           x_range=(0, 5), y_range=(0.001, 10**22),
+           background_fill_color="#fafafa")
 
 p.line(x, np.sqrt(x), legend="y=sqrt(x)",
-       line_color="tomato", line_dash="dotdash")
+       line_color="tomato", line_dash="dashed")
 
 p.line(x, x, legend="y=x")
 p.circle(x, x, legend="y=x")
@@ -24,13 +25,10 @@ p.line(x, x**x, legend="y=x^x",
        line_dash="dotted", line_color="indigo", line_width=2)
 
 p.line(x, 10**(x**2), legend="y=10^(x^2)",
-       line_color="coral", line_dash="dashed", line_width=2)
+       line_color="coral", line_dash="dotdash", line_width=2)
 
 p.legend.location = "top_left"
 
-p.xaxis.axis_label = 'Domain'
-p.yaxis.axis_label = 'Values (log scale)'
-
 output_file("logplot.html", title="log plot example")
 
-show(p)  # open a browser
+show(p)
