@@ -1,6 +1,6 @@
 import numpy as np
 
-from bokeh.models import ColumnDataSource, DataRange1d, Plot, LinearAxis, Grid
+from bokeh.models import ColumnDataSource, Plot, LinearAxis, Grid
 from bokeh.models.markers import DiamondCross
 from bokeh.io import curdoc, show
 
@@ -11,11 +11,8 @@ sizes = np.linspace(10, 20, N)
 
 source = ColumnDataSource(dict(x=x, y=y, sizes=sizes))
 
-xdr = DataRange1d()
-ydr = DataRange1d()
-
 plot = Plot(
-    title=None, x_range=xdr, y_range=ydr, plot_width=300, plot_height=300,
+    title=None, plot_width=300, plot_height=300,
     h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
 
 glyph = DiamondCross(x="x", y="y", size="sizes", line_color="#386cb0", fill_color=None, line_width=2)
