@@ -1,4 +1,4 @@
-from bokeh.models import ColumnDataSource, DataRange1d, Plot, LinearAxis, Grid
+from bokeh.models import ColumnDataSource, Plot, LinearAxis, Grid
 from bokeh.models.glyphs import HexTile
 from bokeh.io import curdoc, show
 
@@ -8,11 +8,8 @@ source = ColumnDataSource(dict(
     )
 )
 
-xdr = DataRange1d()
-ydr = DataRange1d()
-
 plot = Plot(
-    title=None, x_range=xdr, y_range=ydr, plot_width=300, plot_height=300,
+    title=None, plot_width=300, plot_height=300,
     h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
 
 glyph = HexTile(q="q", r="r", size=1, fill_color="#fb9a99", line_color="white")
