@@ -1,6 +1,6 @@
 import numpy as np
 
-from bokeh.models import ColumnDataSource, DataRange1d, Plot, LinearAxis, Grid
+from bokeh.models import ColumnDataSource, Plot, LinearAxis, Grid
 from bokeh.models.glyphs import Text
 from bokeh.io import curdoc, show
 
@@ -12,11 +12,8 @@ text = [a[i*3:i*3+3] for i in range(N)]
 
 source = ColumnDataSource(dict(x=x, y=y, text=text))
 
-xdr = DataRange1d()
-ydr = DataRange1d()
-
 plot = Plot(
-    title=None, x_range=xdr, y_range=ydr, plot_width=300, plot_height=300,
+    title=None, plot_width=300, plot_height=300,
     h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
 
 glyph = Text(x="x", y="y", text="text", angle=0.3, text_color="#96deb3")
